@@ -27,7 +27,7 @@ class PhoneNumber(AnyEntity):
 
 class PostalAddress(AnyEntity):
     __regid__ = 'PostalAddress'
-    fetch_attrs, fetch_order = fetch_config(['street', 'street2', 'postalcode',
+    fetch_attrs, cw_fetch_order = fetch_config(['street', 'street2', 'postalcode',
                                              'city', 'country'])
     def dc_long_title(self):
         lines = []
