@@ -1,4 +1,5 @@
 from yams.buildobjs import EntityType, String, Float
+from yams.constraints import IntervalBoundConstraint
 
 _ = unicode
 
@@ -13,11 +14,15 @@ class PostalAddress(EntityType):
     street  = String(fulltextindexed=True, required=True, maxsize=256)
     street2  = String(fulltextindexed=True, maxsize=256)
     postalcode = String(fulltextindexed=True, required=True, maxsize=256)
-    city    = String(fulltextindexed=True, required=True, maxsize=256)
-    country = String(fulltextindexed=True, maxsize=256)
+    city    = String(fulltextindexed=True, required=True, maxsize=256,
+                     internationalizable=True) # see static-message.pot
+    country = String(fulltextindexed=True, maxsize=256,
+                     internationalizable=True) # see static-message.pot
     state   = String(fulltextindexed=True, maxsize=256)
-    latitude = Float()
-    longitude = Float()
+    latitude = Float(constraints=[IntervalBoundConstraint(-90, 90)],
+                     description=_('latitude in degree'))
+    longitude = Float(constraints=[IntervalBoundConstraint(-180, 180)],
+                     description=_('longitude in degree'))
 
 class IMAddress(EntityType):
     im_account  = String(fulltextindexed=True, required=True, maxsize=64)
